#
# spec file for package xinit
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%define UsrEtcMove 1
%endif
Name:           xinit
Version:        1.4.3
Release:        1.1
Summary:        X Window System initializer
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        xinit.tar.bz2
Source2:        keygen.c
Source3:        keygen.1
Patch0:         xinit.diff
Patch1:         xinit-client-session.patch
Patch2:         xinit-suse.patch
Patch3:         xinit-tolerant-hostname-changes.patch
Patch5:         xinit-tarball.patch
# needed for patch0
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
Requires:       setxkbmap
Requires:       xauth
Requires:       xmodmap
Requires:       xrdb
Requires:       xsetroot
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
%if 0%{?suse_version} > 1320
Requires:       xterm-bin
%else
Requires:       xterm
%endif

%description
The xinit program is used to start the X Window System server and a
first client program on systems that are not using a display manager
such as xdm or in environments that use multiple window systems.
When this first client exits, xinit will kill the X server and then
terminate.

%prep
%setup -q
%if 0%{?UsrEtcMove}
sed -i 's+%{_sysconfdir}/X11+%{_libexecdir}+' %{PATCH0}
%endif
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
### patch is applied later in %install section
%dnl %patch -P 5 -p0
# needed for patch0
autoreconf -fi

%build
%if 0%{?UsrEtcMove}
%configure --with-xinitdir=%{_libexecdir}/xinit
%else
%configure
%endif
%make_build
gcc %{optflags} -o keygen %{SOURCE2}

%install
%make_install
install -m 0644 %{SOURCE3} %{buildroot}%{_mandir}/man1
install -m 0711 keygen %{buildroot}%{_bindir}/keygen
pushd %{buildroot}
tar xf %{SOURCE1}
%if 0%{?UsrEtcMove}
patch -p0 < %{PATCH5}
mkdir -p %{buildroot}%{_libexecdir}/xinit
mv etc/X11/xinit/{xinitrc,xserverrc} %{buildroot}%{_libexecdir}/xinit
mkdir -p usr%{_sysconfdir}/X11/xinit/xinitrc.d
mv etc/X11/Xresources usr%{_sysconfdir}/X11
mv etc/X11/xinit/xinitrc.common usr%{_sysconfdir}/X11/xinit
# Compatibility symlink for user xinitrc files
ln -s %{_prefix}%{_sysconfdir}/X11/xinit/xinitrc.common etc/X11/xinit/xinitrc.common
rmdir etc/X11/xinit/xinitrc.d
%endif
popd

%files
%license COPYING
%doc ChangeLog README.md
%if 0%{?UsrEtcMove}
%dir %{_distconfdir}/X11
%{_distconfdir}/X11/xinit/
%{_distconfdir}/X11/Xresources
%dir %{_libexecdir}/xinit
%attr(0755,root,root) %{_libexecdir}/xinit/xinitrc
%attr(0755,root,root) %{_libexecdir}/xinit/xserverrc
%dir %{_sysconfdir}/X11/xinit/
%config %{_sysconfdir}/X11/xinit/xinitrc.common
%else
%config %{_sysconfdir}/X11/xinit/
%config %{_sysconfdir}/X11/Xresources
%endif
%{_bindir}/keygen
%{_bindir}/startx
%{_bindir}/xinit
%{_mandir}/man1/keygen.1%{?ext_man}
%{_mandir}/man1/startx.1%{?ext_man}
%{_mandir}/man1/xinit.1%{?ext_man}

%changelog
* Sun Jan  5 2025 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.4.3
  * Reindent startx after !6
  * Remove Xdmx from suggested Xserver list
  * Mark global variables as static since there's only one source file
  * Clear -Wunused-parameter warnings from clang
  * Use ptrdiff_t to store results of pointer subtraction
  * Use asprintf() if available
  * Don't exit with failure on SIGTERM regardless.
  * darwin: Remove bashism from 10-tmpdirs script
  * Modernized shell scripts
  * startx: Assign XSERVERRC to correct userserverrc
  * add closing quote to /dev/random mcookie hex
- adjusted xinit-suse.patch
- refreshed xinit-client-session.patch
- refreshed xinit-tolerant-hostname-changes.patch
* Mon Dec 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Properly comment %%patch 5 out: '#' still expands the macro, which
  makes build fail with rpm 4.20. Use %%dnl instead.
* Thu Jul  4 2024 Stefan Dirsch <sndirsch@suse.com>
- xinitrc.common: no longer start nvidia-settings in background in
  order to avoid a zombie process under certain circumstances
  (boo#1227313)
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu May 11 2023 Stefan Dirsch <sndirsch@suse.com>
- revert previous change; cpp is not needed for xinit, but only for
  xdm package
* Thu May 11 2023 Stefan Dirsch <sndirsch@suse.com>
- since xrdb no longer requires cpp, it needs to be reqired here now
* Sun Dec  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.4.2
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * gitlab CI: stop requiring Signed-off-by in commits
  * man page: Update remote display example from rsh to ssh
  * Remove non-portable grep usage from startx
  * Don't wait for X to finish starting if it has died
  * stop unsetting DBUS_SESSION_BUS_ADDRESS variable
  * darwin: Drop support for macOS 10.7 and earlier
  * darwin: Ensure we launch the user startx from $HOME
  * darwin: Specify +extension GLX when the user requests IGLX support
  * darwin: Wait for font_cache to complete to avoid a race with `xset fb=`
  * man: Restore non-SCO UNIX bits of the man page
  * startx: use uname -n instead of hostname
  * startx: Source XINITRC and XSERVERRC variables
  * startx: don't attempt to catch SIGKILL
- supersedes xinit-nolonger-unset-dbus-session.patch
- refreshed xinit-suse.patch
* Wed Apr 21 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir, use https)
* Sun Oct  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Properly track the compatibility symlink
* Tue Sep  8 2020 Stefan Dirsch <sndirsch@suse.com>
- simplified UsrEtcMove enable/disable logic in specfile
* Tue Sep  8 2020 Stefan Dirsch <sndirsch@suse.com>
- xinit-tarball.patch/xinit.spec
  * reenabled move to /usr/etc/X11/xinit
  * fixed remaining issues mentioned in boo#1173052, comment#6
    and boo#1176212, comment#7
* Tue Sep  8 2020 Stefan Dirsch <sndirsch@suse.com>
- reverted move to /usr/etc/X11/xinit for now (boo#1173052, comment#6)
* Sat Sep  5 2020 Stefan Dirsch <sndirsch@suse.com>
- moved xinit files to /usr/etc/X11/xinit and removed xinitrc
  skeleton (boo#1173052)
- xinit-tarball.patch
  * adjust tarball contenct to /usr/etc move (boo#1173052)
* Sun Aug 23 2020 Stefan Dirsch <sndirsch@suse.com>
- xinitrc: SuSE --> SUSE (boo#1175123)
* Tue Mar 24 2020 Stefan Dirsch <sndirsch@suse.com>
- /etc/X11/xinit/xinitrc.common
  * prevent gnome-session from failing by setting
    XDG_SESSION_TYPE to 'x11' (boo#1163262)
* Mon Mar  4 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.4.1
  * This release fixes a bug when too many arguments are supplied
    to the program and improves the man pages.
* Sat Sep 15 2018 sndirsch@suse.com
- xinit-nolonger-unset-dbus-session.patch
  * no longer unset DBUS_SESSION_BUS_ADDRESS variable to prevent
    gnome-session (and probably other DEs or programs, except of
    Plasma) from launching a new D-Bus session, while systemd has
    already launched its own. Unsetting it broke user systemd
    services that use D-Bus (e.g. PulseAudio), because X uses
    another D-Bus session (boo#1108549)
* Wed Jul 11 2018 fcrozat@suse.com
- Do not check /var/lib/X11/X anymore, it is obsolete
  (FATE#325524).
* Wed Apr  4 2018 sndirsch@suse.com
- Update to version 1.4.0
  * autogen.sh: use quoted string variables
  * Remove SCO support for SHELL_CMD and startx man page.
  * Remove support for ancient A/UX 3.0 support
  * Remove left over $(launchagents_DATA) in CLEANFILES
  * startx: Pass -keeptty when telling the server to start on the current tty
  * startx: Fix startx picking an already used display number when -nolock is used
  * remove bogus \/ escapes
  * launchd: Install binaries into libexecdir
  * startx: Add -listen tcp if nolisten_tcp is disabled for XQuartz
  * startx: Add support for enabling IGLX for XQuartz
  * startx: Don't use GNU expr extensions
  * autogen: add default patch prefix
  * startx: fix comment typo
  * startx: don't init defaultdisplay to :0
  * autogen.sh: use exec instead of waiting for configure to finish
  * xinit: check for correct fork error code
* Wed Jun  1 2016 mstaudt@suse.com
- xinitrc.common: Add plasma* in list of fallback WMs
* Wed Jun  1 2016 mstaudt@suse.com
- xinitrc.common: Add comments, make error messages clearer.
  Don't filter out twm, as it's only installed on request.
  Don't expand fallback WINDOWMANAGER.
* Wed Jun  1 2016 werner@suse.de
- xinit.tar.bz2: skip twm and xsession desktops
* Tue May 31 2016 werner@suse.de
- xinit.tar.bz2:
  simplify bash code of /etc/X11/xinit/xinitrc.common to avoid that
  already set WINDOWMANAGER variable becomes stripped (bsc#981437)
* Fri Apr  1 2016 eich@suse.com
- xinit.tar.bz2:
  update /etc/X11/xinit/xinitrc.common to make sure numbered scripts
  are run sequentially. All non-numbered scripts will still be run in
  background to avoid stalling on non-daemonizing 'services' (boo#973559).
* Sun May 10 2015 Led <ledest@gmail.com>
- fix bashism in startx script
- update patches:
  * xinit-suse.patch
* Wed Mar 18 2015 sndirsch@suse.com
- fixed bugnumer reference in previous changelog entry
* Wed Mar 11 2015 werner@suse.de
- Allow WINDOWMANAGER to be a command line string (bsc#921172)
* Wed Jan 28 2015 sndirsch@suse.com
- startx.cpp:
  * /usr/X11R6/bin/X --> /usr/bin/X
  * /var/X11R6/bin/X --> /var/lib/X11/X
- refreshed patches
* Fri Jan 23 2015 sndirsch@suse.com
- apparently with release 1.3.4 xinit needs cc1plus; otherwise
  generation of startx fails and results in a file with a size
  of 0 bytes
* Wed Jan 21 2015 sndirsch@suse.com
- Fixed some more spacing and minor issues in adapted patches
* Tue Jan 20 2015 sfalken@opensuse.org
- Fixed some spacing and single quote vs backtick issues
  in patches
* Mon Jan 19 2015 sfalken@opensuse.org
- Corrections to variable names in xinit-suse.patch and
  xinit-tolerant-hostname-changes.patch
* Sun Jan 18 2015 sfalken@opensuse.org
- Update to version 1.3.4:
  + Changes from 1.3.3
  - Fix warnings about parameters to startServer & startClient
    shadowing globals
  - Pass files to cpp via CLI arg instead of stdin to workaround
    gcc 4.8 change (fdo#69439)
  - Remove unixware / sco support
  - Bump required util-macros version to 1.19
  - Replace $RAWCPPFLAGS with $TRADITIONALCPPFLAGS when processing
    cpp files
  - Under Linux start X on the current VT (rh#806491)
  - startx; Pass vtX as long as the user did not specify one
  - configure: Drop AM_MAINTAINER_MODE
  - autogen.sh: Honor NOCONFIGURE=1
  - startx: Make the bugzilla reference in a comment survive cpp
    processing (fdo#83019)
  - Remove hardcoded path to OpenSSL for OpenBSD
  + Patches refactored/renamed for version change
  + Added:
  - xinit-client-session.patch
  - xinit-tolerant-hostname-changes.patch
  - xinit-suse.patch
  - xinit-1.3.4.tar.bz2
  + Modified:
  - xinit-client-session.patch
  + Dropped:
  - xinit-tolerant-hostname-changes.diff
  - xinit-suse.diff
  - xinit-1.3.3.tar.bz2
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Tue Sep  9 2014 sndirsch@suse.com
- add info to run chkstat after modifying /etc/permissions.local
  in order to run startx (bnc#895647)
* Wed Jan  8 2014 lnussel@suse.de
- don't call the obsolete wmlist. Read /usr/share/xsessions instead.
* Mon Sep 16 2013 sndirsch@suse.com
- fixed loading of .xkb files (bnc#840408)
* Thu Sep 12 2013 zaitor@opensuse.org
- Update to version 1.3.3:
  + Add Apple copyright/license notice from launchd files to
    COPYING.
  + Use pid_t instead of int for type of pids.
  + Check for openssl as mkcookie fallback on all platforms, not
    just OpenBSD.
  + Declare processTimeout() as taking a const string arg.
  + If we have to forcibly kill the Xserver on Solaris, reset
    kbd_mode.
  + Add printf attributes suggested by gcc.
  + install: Use sysconfdir instead of libdir for config files.
  + man: Set correct config file location in man page.
  + privileged_startx: use root:wheel instead of 0:0.
  + XQuartz: Fix an issue where -dpi was not being passed to the
    server despite being set.
  + Annotate Fatal and Fatalx as _X_NORETURN.
  + darwin: Silence a syslog message from defaults.
  + laucnhd:
  - Silence some syslog spam.
  - Fix the destination of moved-aside directories in
    privileged_startx.
  - Load privileged_startx properly on Tiger.
  - Provide more verbose error reporting for launchd checkin
    failures.
  - Don't provide the LaunchAgent on Tiger.
  + launchd/privileged_startx: Improved error resolution.
- Add pkgconfig(xproto) BuildRequires, new dependency.
* Wed Dec  5 2012 werner@suse.de
- Move xinitrc.d sourcing part to xinit.common to make it work
  even with xdm session scripts
- Detect other running X server in xserverrc
* Mon Jul  2 2012 werner@suse.de
- Allow xinitrc scripts to be sourced (bnc#750980)
* Sun Apr 15 2012 vuntz@opensuse.org
- Move /etc/X11/Xresources from xorg-x11 to this package (in
  xinit.tar.bz2), since this is the base package using this file.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.3.2:
  + Use default clientargs, serverargs, and display if none were
    set
  + launchd: Add an option (--with-launchagent-xserver) to set the
    default X11 server
  + startx: Choose an unused $DISPLAY by default on all platforms
    (fdo#1789)
  + Include <sys/time.h> and <sys/resource.h> unconditionally
    (fdo#40632)
  + darwin: Buildfix for Tiger which doesn't have posix_spawn
- Changes from version 1.3.1:
  + launchd: Brownbag fix string compare
  + launchd: console_redirect: Actually read and log the remaining
    data when we get EV_EOF
  + launchd: Enable stdout/stderr redirection to ASL
  + launchd: Fix an array-index-out-of-bounds crasher
  + launchd: Log messages to ASL rather than fprintf
  + launchd: Reorganized layout of launchd sources
  + launchd: Set the correct id for privileged_startx
  + launchd: Silence clang static analyzer
  + launchd: syslog: Use facility org.x rather than user
  + launchd: Update console redirection to work with libdispatch
  + privileged_startx: Prefer /usr/bin/mktemp
  + Rename launchd-id-prefix to bundle-id-prefix
  + Use XORG_MANPAGE_SECTIONS rather than cpprules.in to build man
    pages
  + Build system fixes.
- Rebase xinit.diff.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xinit from xorg-x11. Initial version: 1.3.0.
